const searchInput = document.getElementById("searchInput");
const searchButton = document.getElementById("searchButton");
const searchContainer = document.getElementById("searchContainer");
const suggestionsDiv = document.getElementById("suggestions");

function autoSuggestionResult(listJson) {
    const filteredSuggestions = JSON.parse(listJson);
    suggestionsDiv.innerHTML = "";
    if(filteredSuggestions.length > 0) {
        document.addEventListener("click", handleClickOutside);
        suggestionsDiv.style.display = "block";
        searchContainer.classList.remove("rounded-full", "border-gray-100");
        searchContainer.classList.add("rounded-t-3xl", "border-gray-300");
        filteredSuggestions.forEach(s => {
            const div = document.createElement("div");
            div.textContent = s;
            div.tabIndex = 0;
            div.addEventListener("click", function(e) {
                document.removeEventListener("click", handleClickOutside);
                suggestionsDiv.style.display = "none";
                searchContainer.classList.remove("rounded-t-3xl", "border-gray-300");
                searchContainer.classList.add("rounded-full", "border-gray-100");
                window.location.href = "{SEARCH_ENGINE_URL}" + encodeURIComponent(s);
                searchInput.value = '';
            });
            suggestionsDiv.appendChild(div);
        });
    } else {
        document.removeEventListener("click", handleClickOutside);
        suggestionsDiv.style.display = "none";
        searchContainer.classList.remove("rounded-t-3xl", "border-gray-300");
        searchContainer.classList.add("rounded-full", "border-gray-100");
    }
}

function handleClickOutside(event) {
    if (!suggestionsDiv.contains(event.target) && !searchContainer.contains(event.target)) {
        document.removeEventListener("click", handleClickOutside);
        suggestionsDiv.innerHTML = "";
        suggestionsDiv.style.display = "none";
        searchContainer.classList.remove("rounded-t-3xl", "border-gray-300");
        searchContainer.classList.add("rounded-full", "border-gray-100");
    }
}

if(window.JSInterface && window.JSInterface.searchAutoSuggestion) {
    searchInput.addEventListener("input", function(e) {
        const query = this.value;
        if (query) {
            window.JSInterface.searchAutoSuggestion(query);
        } else {
            document.removeEventListener("click", handleClickOutside);
            suggestionsDiv.innerHTML = "";
            suggestionsDiv.style.display = "none";
            searchContainer.classList.remove("rounded-t-3xl", "border-gray-300");
            searchContainer.classList.add("rounded-full", "border-gray-100");
        }
    });
}
searchButton.addEventListener("click", function(e) {
    const query = searchInput.value;
    if(query != "") {
        window.location.href = "{SEARCH_ENGINE_URL}" + encodeURIComponent(query);
        searchInput.value = '';
    }
});
searchInput.addEventListener("keydown", function(e) {
    if (event.key === "Enter") {
        const query = searchInput.value;
        if(query != "") {
            window.location.href = "{SEARCH_ENGINE_URL}" + encodeURIComponent(query);
            searchInput.value = '';
        }
    }
});
document.querySelectorAll(".tile").forEach(tile => {
    tile.addEventListener("click", function(e) {
        if(window.JSInterface && window.JSInterface.handleBannerClick) {
            window.JSInterface.handleBannerClick(this.getAttribute("data-label"));
        }
    });
});

function updateSpacers() {
    const wrapper = document.querySelector('.search-wrapper');
        const vh = window.innerHeight;
        // Reset padding to measure true height
        wrapper.style.paddingTop = '0px';
        wrapper.style.paddingBottom = '0px';
        const remaining = vh - wrapper.offsetHeight;
        if (remaining > 0) {
          wrapper.style.paddingTop    = `${remaining * {PADDING_TOP}}px`;
          wrapper.style.paddingBottom = `${remaining * {PADDING_BOTTOM}}px`;
        } else {
          wrapper.style.paddingTop = '0px';
          wrapper.style.paddingBottom = '0px';
        }
}
window.addEventListener('load', updateSpacers);
window.addEventListener('resize', updateSpacers);